Todo & planning
===============

* Create a basic wrapper (done)
* ``create`` command (done)

  * Creates a `default directory structure`_ (done)
  
* ``release`` command

  * Version bump (done)
  * Update changelog from git (done)
  * Do the commit (done)
  * Tag it (done)
  * Update PyPi (done)

.. _default directory structure: http://guide.python-distribute.org/creation.html#arranging-your-file-and-directory-structure